
/* -------------------------------------------------------------------------- */

/*

tcl_altfunc.c

USNO/NRL Optical Interferometer
United States Naval Observatory
3450 Massachusetts Avenue, NW
Washington, DC  20392-5420

Subsystem:
----------
My software libraries

Description:
------------
This file contains slightly altered tcl functions.

Functions:
----------
Tcl_GetFloat, Tcl_GetLongInt.

Modification history:
---------------------
1995 Apr 15 - Nicholas Elias, USNO/AD5
	      File created with functions Tcl_GetFloat( ) and Tcl_GetLongInt( ).

*/

/* -------------------------------------------------------------------------- */

/* Includes */

#include "tcl.h"         /* Tcl */

#include "tcl_altfunc.h" /* Alternate tcl function prototypes */

/* -------------------------------------------------------------------------- */

/*

Tcl_GetFloat

Description:
------------
This function converts a character string to a float variable and returns the
tcl result flag.  If this function is unsuccessful, the get value is set to
zero.

Inputs:
-------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.
*psString  - This is the pointer to the 1D char array which contains the string
             to be converted to a float.

Outputs:
--------
*pfGet - This is the pointer to the float variable which contains the get value.

Modification history:
---------------------
1995 Apr 15 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_GetFloat( Tcl_Interp *pmtInterp, char *psString, float *pfGet )

{

  /* Declare the local variables */
  
  int iResult;  /* This is the int variable which contains the tcl result
      flag */
      
  double dfGet; /* This is the double variable which contains the temporary get
                   value */
  
  
  /* Call Tcl_GetDouble( ) and convert the get value to a float, if possible */

  iResult = Tcl_GetDouble( pmtInterp, psString, &dfGet );
  
  if ( iResult == TCL_OK )
  {
    *pfGet = (float) dfGet;
  }
  else
  {
    *pfGet = 0.0;
  }
  
  
  /* Return iResult to the calling function */
  
  return( iResult );

}

/* -------------------------------------------------------------------------- */

/*

Tcl_GetLongInt

Description:
------------
This function converts a character string to a long int variable and returns the
tcl result flag.  If this function is unsuccessful, the get value is set to
zero.

Inputs:
-------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.
*psString  - This is the pointer to the 1D char array which contains the string
             to be converted to a long int.

Outputs:
--------
*pliGet - This is the pointer to the long int variable which contains the get
          value.

Modification history:
---------------------
1995 Apr 15 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_GetLongInt( Tcl_Interp *pmtInterp, char *psString, long int *pliGet )

{

  /* Declare the local variables */
  
  int iResult; /* This is the int variable which contains the tcl result flag */
      
  int iGet;    /* This is the int variable which contains the temporary get
                  value */
  
  
  /* Call Tcl_GetInt( ) and convert the get value to a long int, if possible */

  iResult = Tcl_GetInt( pmtInterp, psString, &iGet );
  
  if ( iResult == TCL_OK )
  {
    *pliGet = (long int) iGet;
  }
  else
  {
    *pliGet = 0;
  }
  
  
  /* Return iResult to the calling function */
  
  return( iResult );

}
